==> nextcloud-11.0.2.tgz: nextcloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Przechowywanie jest czasowo niedostępne",
    "Storage invalid" : "Pamięć nieprawidłowa",
    "Unknown error" : "Nieznany błąd",
    "All files" : "Wszystkie pliki",
    "Recent" : "Ostatnie",
    "File could not be found" : "Nie można odnaleźć pliku",
    "Home" : "Dom",
    "Close" : "Zamknij",
    "Favorites" : "Ulubione",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć folderu „{dir}”",
    "Upload cancelled." : "Wczytywanie anulowane.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Folder docelowy \"{dir}\" nie istnieje więcej",
    "Not enough free space" : "Za mało wolnego miejsca",
    "Uploading..." : "Wgrywanie....",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Actions" : "Akcje",
    "Download" : "Pobierz",
    "Rename" : "Zmień nazwę",
    "Move" : "Przenieść",
    "Target folder" : "Folder docelowy",
    "Delete" : "Usuń",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj udostępnianie",
    "Could not load info for file \"{file}\"" : "Nie można było załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem.",
    "Could not move \"{file}\", target exists" : "Nie można było przenieść „{file}” – plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można było przenieść \"{file}\"",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest juz używana w folderze \"{dir}\". Proszę wybrać inną nazwę.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można było utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można było utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć folderu „{dir}”, ponieważ już istnieje.",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku „{fileName}”.",
    "No search results in other folders for '{tag}{filter}{endtag}'" : "Brak wyników wyszukiwania w innych folderach dla '{tag}{filter}{endtag}'",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Modyfikacja",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wczytywania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca {owner}, pliki nie mogą zostać zaktualizowane lub synchronizowane! ",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["pasujący '{filter}'","pasujące '{filter}'","pasujących '{filter}'","pasujących '{filter}'"],
    "View in folder" : "Zobacz w katalogu",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubiony",
    "Favorite" : "Ulubione",
    "Copy local link" : "Kopiowanie lokalnego linku",
    "Folder" : "Folder",
    "New folder" : "Nowy folder",
    "Upload" : "Wyślij",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas aktualizacji tagów",
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "You created {file}" : "Utworzy‭łeś {file}",
    "{user} created {file}" : "{user} utworzy‭ł {file}",
    "{file} was created in a public folder" : "{file} został utworzony w folderze publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z Twoich <strong>ulubionych</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Plik lub folder został <strong>zmieniony</ strong> lub <strong>zastąpiony</ strong>",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub folder został <strong>utworzony</strong>",
    "A new file or folder has been <strong>deleted</strong>" : "Nowy plik lub folder jest <strong>usunięty </strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ogranicz powiadomienia o utworzeniu i zmianach do swoich <strong>ulubionych plików</strong> <em>(Tylko w strumieniu aktywności)</em>",
    "A new file or folder has been <strong>restored</strong>" : "Nowy plik lub folder jest <strong>przywrócony</strong>",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "File handling" : "Zarządzanie plikami",
    "Maximum upload size" : "Maksymalny rozmiar wysyłanego pliku",
    "max. possible: " : "maks. możliwy:",
    "Save" : "Zapisz",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Z PHP-FPM zastosowanie zmian może zająć 5 minut.",
    "Missing permissions to edit from here." : "Brakuje uprawnień do edycji.",
    "Settings" : "Ustawienia",
    "Show hidden files" : "Pokaż ukryte pliki",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Ładowany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites" : "Brak ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Shared with you" : "Udostępnione dla Ciebie",
    "Shared with others" : "Udostępnione przez Ciebie",
    "Shared by link" : "Udostępnione przez link",
    "Tags" : "Tagi",
    "Deleted files" : "Usunięte pliki",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "Storage not available" : "Zasoby dysku są niedostępne",
    "Unable to set upload directory." : "Nie można ustawić katalog wczytywania.",
    "Invalid Token" : "Nieprawidłowy Token",
    "No file was uploaded. Unknown error" : "Żaden plik nie został załadowany. Nieznany błąd",
    "There is no error, the file uploaded with success" : "Nie było błędów, plik wysłano poprawnie.",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini: " : "Wgrany plik przekracza wartość upload_max_filesize zdefiniowaną w php.ini: ",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Wysłany plik przekracza wielkość dyrektywy MAX_FILE_SIZE określonej w formularzu HTML",
    "The uploaded file was only partially uploaded" : "Załadowany plik został wysłany tylko częściowo.",
    "No file was uploaded" : "Nie wysłano żadnego pliku",
    "Missing a temporary folder" : "Brak folderu tymczasowego",
    "Failed to write to disk" : "Błąd zapisu na dysk",
    "Not enough storage available" : "Za mało dostępnego miejsca",
    "The target folder has been moved or deleted." : "Folder docelowy został przeniesiony lub usunięty",
    "Upload failed. Could not find uploaded file" : "Nieudane przesłanie. Nie można znaleźć przesyłanego pliku",
    "Upload failed. Could not get file info." : "Nieudane przesłanie. Nie można pobrać informacji o pliku.",
    "Invalid directory." : "Zła ścieżka.",
    "Total file size {size1} exceeds upload limit {size2}" : "Całkowity rozmiar {size1} przekracza limit uploadu {size2}",
    "Error uploading file \"{fileName}\": {message}" : "Błąd podczas przekazywania \"{fileName}\": {message}",
    "Could not get result from server." : "Nie można uzyskać wyniku z serwera.",
    "{hours}:{minutes}:{seconds} hour{plural_s} left" : "Pozostało {hours}:{minutes}:{seconds} hour{plural_s} ",
    "{hours}:{minutes}h" : "{hours}:{minutes}godz.",
    "{minutes}:{seconds} minute{plural_s} left" : "Pozostało {minutes}:{seconds} minute{plural_s}",
    "{minutes}:{seconds}m" : "{minutes}:{seconds}min.",
    "{seconds} second{plural_s} left" : "Pozostało sekund: {seconds}",
    "{seconds}s" : "{seconds} s",
    "Any moment now..." : "Jeszcze chwilę...",
    "Soon..." : "Wkrótce...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Wysyłanie pliku jest w toku. Jeśli opuścisz tę stronę, wysyłanie zostanie przerwane.",
    "No entries in this folder match '{filter}'" : "Brak wyników pasujących do '{filter}'",
    "Local link" : "Lokalny odnośnik",
    "{newname} already exists" : "{newname} już istnieje",
    "A file or folder has been <strong>changed</strong>" : "Plik lub folder został <strong>zmieniony</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Plik lub folder został <strong>usunięty</strong>",
    "A file or folder has been <strong>restored</strong>" : "Plik lub folder został <strong>przywrócony</strong>",
    "You created %1$s" : "Utworzyłeś %1$s",
    "%2$s created %1$s" : "%2$s utworzył %1$s",
    "%1$s was created in a public folder" : "%1$s został utworzony w folderze publicznym",
    "You changed %1$s" : "Zmieniłeś %1$s",
    "%2$s changed %1$s" : "%2$s zmienił %1$s",
    "You deleted %1$s" : "Usunąłeś %1$s",
    "%2$s deleted %1$s" : "%2$s usunął %1$s",
    "You restored %1$s" : "Przywróciłeś %1$s",
    "%2$s restored %1$s" : "%2$s przywrócił %1$s",
    "Changed by %2$s" : "Zmienione przez %2$s",
    "Deleted by %2$s" : "Usunięte przez %2$s",
    "Restored by %2$s" : "Przywrócone przez %2$s",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["Pozostała {hours}:{minutes}:{seconds} godzina","Pozostało {hours}:{minutes}:{seconds} godzin","Pozostało {hours}:{minutes}:{seconds} godzin"],
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["Pozostała {minutes}:{seconds} minuta","Pozostało {minutes}:{seconds} minut","Pozostało {minutes}:{seconds} minut"],
    "_{seconds} second left_::_{seconds} seconds left_" : ["Pozostała {seconds} sekunda","Pozostało {seconds} sekund","Pozostało {seconds} sekund"]
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>=14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-12.0.2.tgz: nextcloud/apps/files/l10n/pl.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Magazyn jest tymczasowo niedostępny",
    "Storage invalid" : "Nieprawidłowy magazyn",
    "Unknown error" : "Nieznany błąd",
    "All files" : "Wszystkie pliki",
    "Recent" : "Ostatnie",
    "File could not be found" : "Nie można odnaleźć pliku",
    "Home" : "Dom",
    "Close" : "Zamknij",
    "Favorites" : "Ulubione",
    "Could not create folder \"{dir}\"" : "Nie można utworzyć folderu „{dir}”",
    "Upload cancelled." : "Wczytywanie anulowane.",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nie można przesłać {filename} być może jest katalogiem lub posiada 0 bajtów",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Brak wolnej przestrzeni, przesyłasz {size1} a pozostało tylko {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Folder docelowy \"{dir}\" nie istnieje więcej",
    "Not enough free space" : "Za mało wolnego miejsca",
    "Uploading..." : "Wgrywanie....",
    "..." : "...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Actions" : "Akcje",
    "Download" : "Pobierz",
    "Rename" : "Zmień nazwę",
    "Move" : "Przenieść",
    "Target folder" : "Folder docelowy",
    "Delete" : "Usuń",
    "Disconnect storage" : "Odłącz magazyn",
    "Unshare" : "Zatrzymaj udostępnianie",
    "Could not load info for file \"{file}\"" : "Nie można było załadować informacji o pliku \"{file}\"",
    "Files" : "Pliki",
    "Details" : "Szczegóły",
    "Select" : "Wybierz",
    "Pending" : "Oczekujące",
    "Unable to determine date" : "Nie można ustalić daty",
    "This operation is forbidden" : "Ta operacja jest niedozwolona",
    "This directory is unavailable, please check the logs or contact the administrator" : "Ten folder jest niedostępny, proszę sprawdzić logi lub skontaktować się z administratorem.",
    "Could not move \"{file}\", target exists" : "Nie można było przenieść „{file}” – plik o takiej nazwie już istnieje",
    "Could not move \"{file}\"" : "Nie można było przenieść \"{file}\"",
    "{newName} already exists" : "{newName} już istnieje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie można zmienić nazwy \"{fileName}\", plik nie istnieje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Nazwa \"{targetName}\" jest juz używana w folderze \"{dir}\". Proszę wybrać inną nazwę.",
    "Could not rename \"{fileName}\"" : "Nie można zmienić nazwy \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nie można było utworzyć pliku \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie można było utworzyć pliku \"{file}\", ponieważ ten plik już istnieje.",
    "Could not create folder \"{dir}\" because it already exists" : "Nie można utworzyć folderu „{dir}”, ponieważ już istnieje.",
    "Error deleting file \"{fileName}\"." : "Błąd podczas usuwania pliku „{fileName}”.",
    "No search results in other folders for {tag}{filter}{endtag}" : "Brak wyników wyszukiwania w innych folderach dla {tag}{filter}{endtag}",
    "Name" : "Nazwa",
    "Size" : "Rozmiar",
    "Modified" : "Modyfikacja",
    "_%n folder_::_%n folders_" : ["%n katalog","%n katalogi","%n katalogów","%n katalogów"],
    "_%n file_::_%n files_" : ["%n plik","%n pliki","%n plików","%n plików"],
    "{dirs} and {files}" : "{dirs} i {files}",
    "_including %n hidden_::_including %n hidden_" : ["w tym %n ukryty","w tym %n ukryte","w tym %n ukrytych","w tym %n ukrytych"],
    "You don’t have permission to upload or create files here" : "Nie masz uprawnień do wczytywania lub tworzenia plików w tym miejscu",
    "_Uploading %n file_::_Uploading %n files_" : ["Wysyłanie %n pliku","Wysyłanie %n plików","Wysyłanie %n plików","Wysyłanie %n plików"],
    "New" : "Nowy",
    "\"{name}\" is an invalid file name." : "\"{name}\" jest nieprawidłową nazwą pliku.",
    "File name cannot be empty." : "Nazwa pliku nie może być pusta.",
    "\"{name}\" is not an allowed filetype" : "typ pliku \"{name}\" nie jest dozwolony",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Brak wolnego miejsca dla {owner}, pliki nie mogą zostać zaktualizowane lub synchronizowane! ",
    "Your storage is full, files can not be updated or synced anymore!" : "Magazyn jest pełny. Pliki nie mogą zostać zaktualizowane lub zsynchronizowane!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Miejsce dla {owner} jest na wyczerpaniu ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Twój magazyn jest prawie pełny ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["pasujący '{filter}'","pasujące '{filter}'","pasujących '{filter}'","pasujących '{filter}'"],
    "View in folder" : "Zobacz w katalogu",
    "Copied!" : "Skopiowano!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Skopiuj link bezpośredni (działa tylko dla użytkowników, którzy mają dostęp do pliku/folderu)",
    "Path" : "Ścieżka",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtów","%n bajtów"],
    "Favorited" : "Ulubiony",
    "Favorite" : "Ulubione",
    "New folder" : "Nowy folder",
    "Upload file" : "Załaduj plik",
    "An error occurred while trying to update the tags" : "Wystąpił błąd podczas aktualizacji tagów",
    "Added to favorites" : "Dodano do ulubionych",
    "Removed from favorites" : "Usunięto z ulubionych",
    "You added {file} to your favorites" : "Dodałeś {file} do ulubionych",
    "You removed {file} from your favorites" : "Usunąłeś {file} z ulubionych",
    "File changes" : "Zmiany w plikach",
    "Created by {user}" : "Utworzone przez {user}",
    "Changed by {user}" : "Zmienione przez {user}",
    "Deleted by {user}" : "Usunięte przez {user}",
    "Restored by {user}" : "Przywrócone przez {user}",
    "Renamed by {user}" : "Zmienione przez {user}",
    "Moved by {user}" : "Przeniesione przez {user}",
    "\"remote user\"" : "\"użytkownik zdalny\"",
    "You created {file}" : "Utworzy‭łeś {file}",
    "{user} created {file}" : "{user} utworzy‭ł {file}",
    "{file} was created in a public folder" : "{file} został utworzony w folderze publicznym",
    "You changed {file}" : "Zmieniłeś {file}",
    "{user} changed {file}" : "{user} zmienił {file}",
    "You deleted {file}" : "Usunąłeś {file}",
    "{user} deleted {file}" : "{user} usunął {file}",
    "You restored {file}" : "Przywróciłeś {file}",
    "{user} restored {file}" : "{user} przywrócił {file}",
    "You renamed {oldfile} to {newfile}" : "Zmieniłeś {oldfile} na {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} zmienił {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Przeniosłeś {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} przeniósł {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Plik został dodany lub usunięty z Twoich <strong>ulubionych</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Plik lub folder został <strong>zmieniony</ strong> lub <strong>zastąpiony</ strong>",
    "A new file or folder has been <strong>created</strong>" : "Nowy plik lub folder został <strong>utworzony</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Ogranicz powiadomienia o utworzeniu i zmianach do swoich <strong>ulubionych plików</strong> <em>(Tylko w strumieniu aktywności)</em>",
    "Unlimited" : "Bez limitu",
    "Upload (max. %s)" : "Wysyłka (max. %s)",
    "File handling" : "Zarządzanie plikami",
    "Maximum upload size" : "Maksymalny rozmiar wysyłanego pliku",
    "max. possible: " : "maks. możliwy:",
    "Save" : "Zapisz",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Z PHP-FPM zastosowanie zmian może zająć 5 minut.",
    "Missing permissions to edit from here." : "Brakuje uprawnień do edycji.",
    "%s of %s used" : "Używany %s z %s",
    "%s used" : "%sużywany",
    "Settings" : "Ustawienia",
    "Show hidden files" : "Pokaż ukryte pliki",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">access your Files via WebDAV</a>" : "Użyj tego adresu aby uzyskać <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">dostęp do swoich plików poprzez WebDAV</a>",
    "No files in here" : "Brak plików",
    "Upload some content or sync with your devices!" : "Wgraj coś, albo wykonaj synchronizację ze swoimi urządzeniami.",
    "No entries found in this folder" : "Brak wpisów w tym folderze",
    "Select all" : "Wybierz wszystko",
    "Upload too large" : "Ładowany plik jest za duży",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Pliki, które próbujesz przesłać, przekraczają maksymalną dopuszczalną wielkość.",
    "No favorites yet" : "Brak jeszcze ulubionych",
    "Files and folders you mark as favorite will show up here" : "Pliki i katalogi, które oznaczysz jako ulubione wyświetlą się tutaj",
    "Shared with you" : "Udostępnione dla Ciebie",
    "Shared with others" : "Udostępnione przez Ciebie",
    "Shared by link" : "Udostępnione przez link",
    "Tags" : "Tagi",
    "Deleted files" : "Usunięte pliki",
    "Text file" : "Plik tekstowy",
    "New text file.txt" : "Nowy plik tekstowy.txt",
    "_{hours}:{minutes}:{seconds} hour left_::_{hours}:{minutes}:{seconds} hours left_" : ["Pozostała {hours}:{minutes}:{seconds} godzina","Pozostało {hours}:{minutes}:{seconds} godzin","Pozostało {hours}:{minutes}:{seconds} godzin"],
    "{hours}:{minutes}h" : "{hours}:{minutes}godz.",
    "_{minutes}:{seconds} minute left_::_{minutes}:{seconds} minutes left_" : ["Pozostała {minutes}:{seconds} minuta","Pozostało {minutes}:{seconds} minut","Pozostało {minutes}:{seconds} minut"],
    "{minutes}:{seconds}m" : "{minutes}:{seconds}min.",
    "_{seconds} second left_::_{seconds} seconds left_" : ["Pozostała {seconds} sekunda","Pozostało {seconds} sekund","Pozostało {seconds} sekund"],
    "{seconds}s" : "{seconds} s",
    "Any moment now..." : "Jeszcze chwilę...",
    "Soon..." : "Wkrótce...",
    "File upload is in progress. Leaving the page now will cancel the upload." : "Wysyłanie pliku jest w toku. Jeśli opuścisz tę stronę, wysyłanie zostanie przerwane.",
    "Copy local link" : "Kopiowanie lokalnego linku",
    "Folder" : "Folder",
    "Upload" : "Wyślij",
    "A new file or folder has been <strong>deleted</strong>" : "Nowy plik lub folder został <strong>usunięty </strong>",
    "A new file or folder has been <strong>restored</strong>" : "Nowy plik lub folder został <strong>przywrócony</strong>",
    "No favorites" : "Brak ulubionych"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
